pub struct BufferedPhysicalDrive {
pub geometry: DiskGeometry,
/* private fields */
}Expand description
Gives buffered direct access to a physical drive to enable random access.
Also see PhysicalDrive.
Fields
geometry: DiskGeometryThe DiskGeometry of the drive.
Implementations
Sourceimpl BufferedPhysicalDrive
impl BufferedPhysicalDrive
Sourcepub fn open(drive_num: u8) -> Result<Self, String>
pub fn open(drive_num: u8) -> Result<Self, String>
Opens the physical drive with the given number.
NOTE: this requires administrator privileges. Drive numbers start at 0.
Fails if an invalid drive number is given, the user has insufficient privileges or an error occures while opening the drive. If an error occurs, an error message containing the error number is returned, see here for a list.