pub struct HarddiskVolume {
pub geometry: DiskGeometry,
pub partition_info: PartitionInfo,
/* private fields */
}Expand description
Gives direct access to a harddisk volume.
NOTE: because of Win32 restrictions, you must read() whole sectors and must only seek() to sector
boundaries. If you need random access, use BufferedHarddiskVolume.
Fields
geometry: DiskGeometryThe DiskGeometry of the drive this volume is located on.
partition_info: PartitionInfoThe PartitionInfo of the volume.
Implementations
Sourceimpl HarddiskVolume
impl HarddiskVolume
Sourcepub fn open(volume_num: u8) -> Result<Self, String>
pub fn open(volume_num: u8) -> Result<Self, String>
Opens the harddisk volume with the given number.
NOTE: this requires administrator privileges. Volume numbers start at 1.
Fails if an invalid harddisk volume number is given, the user has insufficient privileges or an error occures while opening the volume. If an error occurs, an error message containing the error number is returned, see here for a list.