PhysicalDrive

Struct PhysicalDrive 

pub struct PhysicalDrive {
    pub geometry: DiskGeometry,
    /* private fields */
}
Gives direct access to a physical drive.

NOTE: because of Win32 restrictions, you must read() whole sectors and must only seek() to sector boundaries. If you need random access, use BufferedPhysicalDrive.

Fields

geometry: DiskGeometry

The DiskGeometry of the drive.

Implementations

Source

impl PhysicalDrive

pub fn open(drive_num: u8) -> Result<Self, String>

Opens the physical drive with the given number.

NOTE: this requires administrator privileges. Drive numbers start at 0.

Fails if an invalid drive number is given, the user has insufficient privileges or an error occures while opening the drive. If an error occurs, an error message containing the error number is returned, see here for a list.

pub fn size(&self) -> u64

The size of the drive in bytes.