pub struct BufferedHarddiskVolume {
pub geometry: DiskGeometry,
pub partition_info: PartitionInfo,
/* private fields */
}Expand description
Gives buffered direct access to a harddisk volume to enable random access.
Also see HarddiskVolume.
Fields
geometry: DiskGeometryThe DiskGeometry of the drive this volume is located on.
partition_info: PartitionInfoThe PartitionInfo of the volume.
Implementations
Sourceimpl BufferedHarddiskVolume
impl BufferedHarddiskVolume
Sourcepub fn open(volume_num: u8) -> Result<Self, String>
pub fn open(volume_num: u8) -> Result<Self, String>
Opens the harddisk volume with the given number.
NOTE: this requires administrator privileges. Volume numbers start at 1.
Fails if an invalid harddisk volume number is given, the user has insufficient privileges or an error occures while opening the colume. If an error occurs, an error message containing the error number is returned, see here for a list.